@@ -7,6 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_ssm import (
         Client,
+        CommandExecutedWaiter,
         DescribeActivationsPaginator,
         DescribeAssociationExecutionTargetsPaginator,
         DescribeAssociationExecutionsPaginator,
@@ -29,12 +30,15 @@ Usage::
         DescribeMaintenanceWindowTasksPaginator,
         DescribeMaintenanceWindowsForTargetPaginator,
         DescribeMaintenanceWindowsPaginator,
+        DescribeOpsItemsPaginator,
         DescribeParametersPaginator,
         DescribePatchBaselinesPaginator,
         DescribePatchGroupsPaginator,
+        DescribePatchPropertiesPaginator,
         DescribeSessionsPaginator,
         GetInventoryPaginator,
         GetInventorySchemaPaginator,
+        GetOpsSummaryPaginator,
         GetParameterHistoryPaginator,
         GetParametersByPathPaginator,
         ListAssociationVersionsPaginator,
@@ -55,6 +59,8 @@ Usage::
     client: SSMClient = boto3.client("ssm")
     session_client: SSMClient = session.client("ssm")
 
+    command_executed_waiter: CommandExecutedWaiter = client.get_waiter("command_executed")
+
     describe_activations_paginator: DescribeActivationsPaginator = client.get_paginator("describe_activations")
     describe_association_execution_targets_paginator: DescribeAssociationExecutionTargetsPaginator = client.get_paginator("describe_association_execution_targets")
     describe_association_executions_paginator: DescribeAssociationExecutionsPaginator = client.get_paginator("describe_association_executions")
@@ -77,12 +83,15 @@ Usage::
     describe_maintenance_window_tasks_paginator: DescribeMaintenanceWindowTasksPaginator = client.get_paginator("describe_maintenance_window_tasks")
     describe_maintenance_windows_paginator: DescribeMaintenanceWindowsPaginator = client.get_paginator("describe_maintenance_windows")
     describe_maintenance_windows_for_target_paginator: DescribeMaintenanceWindowsForTargetPaginator = client.get_paginator("describe_maintenance_windows_for_target")
+    describe_ops_items_paginator: DescribeOpsItemsPaginator = client.get_paginator("describe_ops_items")
     describe_parameters_paginator: DescribeParametersPaginator = client.get_paginator("describe_parameters")
     describe_patch_baselines_paginator: DescribePatchBaselinesPaginator = client.get_paginator("describe_patch_baselines")
     describe_patch_groups_paginator: DescribePatchGroupsPaginator = client.get_paginator("describe_patch_groups")
+    describe_patch_properties_paginator: DescribePatchPropertiesPaginator = client.get_paginator("describe_patch_properties")
     describe_sessions_paginator: DescribeSessionsPaginator = client.get_paginator("describe_sessions")
     get_inventory_paginator: GetInventoryPaginator = client.get_paginator("get_inventory")
     get_inventory_schema_paginator: GetInventorySchemaPaginator = client.get_paginator("get_inventory_schema")
+    get_ops_summary_paginator: GetOpsSummaryPaginator = client.get_paginator("get_ops_summary")
     get_parameter_history_paginator: GetParameterHistoryPaginator = client.get_paginator("get_parameter_history")
     get_parameters_by_path_paginator: GetParametersByPathPaginator = client.get_paginator("get_parameters_by_path")
     list_association_versions_paginator: ListAssociationVersionsPaginator = client.get_paginator("list_association_versions")
@@ -121,12 +130,15 @@ from mypy_boto3_ssm.paginator import (
     DescribeMaintenanceWindowsPaginator,
     DescribeMaintenanceWindowTargetsPaginator,
     DescribeMaintenanceWindowTasksPaginator,
+    DescribeOpsItemsPaginator,
     DescribeParametersPaginator,
     DescribePatchBaselinesPaginator,
     DescribePatchGroupsPaginator,
+    DescribePatchPropertiesPaginator,
     DescribeSessionsPaginator,
     GetInventoryPaginator,
     GetInventorySchemaPaginator,
+    GetOpsSummaryPaginator,
     GetParameterHistoryPaginator,
     GetParametersByPathPaginator,
     ListAssociationsPaginator,
@@ -140,12 +152,14 @@ from mypy_boto3_ssm.paginator import (
     ListResourceComplianceSummariesPaginator,
     ListResourceDataSyncPaginator,
 )
+from mypy_boto3_ssm.waiter import CommandExecutedWaiter
 
 Client = SSMClient
 
 
 __all__ = (
     "Client",
+    "CommandExecutedWaiter",
     "DescribeActivationsPaginator",
     "DescribeAssociationExecutionTargetsPaginator",
     "DescribeAssociationExecutionsPaginator",
@@ -168,12 +182,15 @@ __all__ = (
     "DescribeMaintenanceWindowTasksPaginator",
     "DescribeMaintenanceWindowsForTargetPaginator",
     "DescribeMaintenanceWindowsPaginator",
+    "DescribeOpsItemsPaginator",
     "DescribeParametersPaginator",
     "DescribePatchBaselinesPaginator",
     "DescribePatchGroupsPaginator",
+    "DescribePatchPropertiesPaginator",
     "DescribeSessionsPaginator",
     "GetInventoryPaginator",
     "GetInventorySchemaPaginator",
+    "GetOpsSummaryPaginator",
     "GetParameterHistoryPaginator",
     "GetParametersByPathPaginator",
     "ListAssociationVersionsPaginator",
